summaryrefslogtreecommitdiff
path: root/test/files/pos/t5877.scala
diff options
context:
space:
mode:
Diffstat (limited to 'test/files/pos/t5877.scala')
-rw-r--r--test/files/pos/t5877.scala4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/files/pos/t5877.scala b/test/files/pos/t5877.scala
index c7827df99f..939013cd01 100644
--- a/test/files/pos/t5877.scala
+++ b/test/files/pos/t5877.scala
@@ -7,8 +7,8 @@ package foo {
}
package object foo {
- // Crasher: No synthetics for method PimpedFoo2: synthetics contains
- implicit class PimpedFoo2(value: Foo) {
+ // Crasher: No synthetics for method EnrichedFoo2: synthetics contains
+ implicit class EnrichedFoo2(value: Foo) {
def huzzah = ""
}
}